from threading import Event

from flask import Flask
import pigpio

from pi_soulra import __version__
from pi_soulra.ir import send


app = Flask(__name__)

power_state = Event()
pi = pigpio.pi()


@app.route("/")
def hello_world():
    return f"<p>Pi Soulra - Version {__version__}</p>"


@app.route("/power_on")
def power_on():
    if not power_state.is_set():
        power_state.set()
        send(pi, ["power", "aux"])

    return "", 204


@app.route("/power_off")
def power_off():
    if power_state.is_set():
        power_state.clear()
        send(pi, ["power"])

    return "", 204


@app.route("/volume_up")
def volume_up():
    send(pi, ["volume-up"])
    return "", 204


@app.route("/volume_down")
def volume_down():
    send(pi, ["volume-down"])
    return "", 204


@app.route("/aux")
def aux():
    send(pi, ["aux"])
    return "", 204


@app.route("/bass")
def bass():
    send(pi, ["bass"])
    return "", 204


def main():
    app.run(host="0.0.0.0", port=8080, threaded=False)  # nosec


main()
